@@ -55,6 +55,8 @@ PY2 = sys.version_info[0] == 2
 # pytest 4.2 handles unittest setup/teardown itself via wrapping fixtures.
 _handle_unittest_methods = parse_version(pytest.__version__) < parse_version("4.2")
 
+_report_header = []
+
 
 # ############### pytest hooks ################
 
@@ -287,39 +289,25 @@ def pytest_load_initial_conftests(early_config, parser, args):
     ):
         os.environ[INVALID_TEMPLATE_VARS_ENV] = "true"
 
-    # Configure DJANGO_SETTINGS_MODULE
-    if options.ds:
-        ds_source = "command line option"
-        ds = options.ds
-    elif SETTINGS_MODULE_ENV in os.environ:
-        ds = os.environ[SETTINGS_MODULE_ENV]
-        ds_source = "environment variable"
-    elif early_config.getini(SETTINGS_MODULE_ENV):
-        ds = early_config.getini(SETTINGS_MODULE_ENV)
-        ds_source = "ini file"
-    else:
-        ds = None
-        ds_source = None
+    def _get_option_with_source(option, envname):
+        if option:
+            return option, "option"
+        if envname in os.environ:
+            return os.environ[envname], "env"
+        cfgval = early_config.getini(envname)
+        if cfgval:
+            return cfgval, "ini"
+        return None, None
 
-    if ds:
-        early_config._dsm_report_header = "Django settings: %s (from %s)" % (
-            ds,
-            ds_source,
-        )
-    else:
-        early_config._dsm_report_header = None
-
-    # Configure DJANGO_CONFIGURATION
-    dc = (
-        options.dc
-        or os.environ.get(CONFIGURATION_ENV)
-        or early_config.getini(CONFIGURATION_ENV)
-    )
+    ds, ds_source = _get_option_with_source(options.ds, SETTINGS_MODULE_ENV)
+    dc, dc_source = _get_option_with_source(options.dc, CONFIGURATION_ENV)
 
     if ds:
+        _report_header.append("settings: %s (from %s)" % (ds, ds_source))
         os.environ[SETTINGS_MODULE_ENV] = ds
 
         if dc:
+            _report_header.append("configuration: %s (from %s)" % (dc, dc_source))
             os.environ[CONFIGURATION_ENV] = dc
 
             # Install the django-configurations importer
@@ -337,9 +325,9 @@ def pytest_load_initial_conftests(early_config, parser, args):
     _setup_django()
 
 
-def pytest_report_header(config):
-    if config._dsm_report_header:
-        return [config._dsm_report_header]
+def pytest_report_header():
+    if _report_header:
+        return ["django: " + ", ".join(_report_header)]
 
 
 @pytest.mark.trylast
@@ -427,7 +415,7 @@ def pytest_runtest_setup(item):
             _disable_class_methods(item.cls)
 
 
-def pytest_collection_modifyitems(session, config, items):
+def pytest_collection_modifyitems(items):
     def get_order_number(test):
         marker_db = test.get_closest_marker('django_db')
         if marker_db:
@@ -565,7 +553,7 @@ def _dj_autoclear_mailbox():
 
 
 @pytest.fixture(scope="function")
-def mailoutbox(monkeypatch, django_mail_patch_dns, _dj_autoclear_mailbox):
+def mailoutbox(django_mail_patch_dns, _dj_autoclear_mailbox):
     if not django_settings_is_configured():
         return
 
@@ -582,7 +570,7 @@ def django_mail_patch_dns(monkeypatch, django_mail_dnsname):
 
 
 @pytest.fixture(scope="function")
-def django_mail_dnsname(monkeypatch):
+def django_mail_dnsname():
     return "fake-tests.example.com"
 
 
@@ -617,7 +605,7 @@ def _django_set_urlconf(request):
 
 
 @pytest.fixture(autouse=True, scope="session")
-def _fail_for_invalid_template_variable(request):
+def _fail_for_invalid_template_variable():
     """Fixture that fails for invalid variables in templates.
 
     This fixture will fail each test that uses django template rendering
